# scappamento
#### B2B automation for music stores

Supported suppliers / platforms:
- [x] Yamaha
- [x] Fender
- [x] Frenexport
- [ ] Proel (WIP)
- [x] Suonostore
- [ ] MusicPool (WIP, broken)
- [x] acquistinretepa
- [x] Mogar (Encoding conversion)

:broccoli:

New commit labels: `fix`, `feat`, `test`, `refactor`, `perf`